/*
ScheduleTogether Backend
Copyright (C) 2024, Zervó Zadachin

DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License version 3
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License version 3 for more details.

This program incorporates external libraries for certain functionalities.
These libraries are covered by their respective licenses, and their usage
agreements are as outlined in their respective documentation or source
code.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package users

import (
	"github.com/kataras/iris/v12"

	db "git.zervo.org/scheduletogether/backend/internal/database"
	"git.zervo.org/scheduletogether/backend/pkg/helpers/request"
	"git.zervo.org/scheduletogether/backend/pkg/types"
)

// UsersGetSelf_Service gets all users from the database
func UsersGetSelf_Service(ctx iris.Context) {
	// Get requesting user's ID from JWT claims
	claims := request.GetUserClaims(ctx)
	id := claims.UserId

	// Get user from database
	var user []db.User
	err := db.Db.Model(&db.User{}).Where("id = ?", id).Select("id", "username", "email", "uuid", "role", "first_name", "last_name", "verified", "friends").Find(&user).Error
	if err != nil {
		ctx.StatusCode(iris.StatusInternalServerError)
		ctx.JSON(types.CommonErrorResponse{
			Error: "Failed to retrieve user",
		})
		logboi.Warn("Failed to retrieve user from the database: " + err.Error())
		return
	}

	// Return user
	ctx.JSON(user)
}
